"use strict";
/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.deletePackage = void 0;
const packageUtils_1 = require("../utils/packageUtils");
async function deletePackage(idOrAlias, project, connection, undelete) {
    const packageId = project.getPackageIdFromAlias(idOrAlias) ?? idOrAlias;
    (0, packageUtils_1.validateId)(packageUtils_1.BY_LABEL.PACKAGE_ID, packageId);
    const request = {};
    request.Id = packageId;
    const isUndelete = undelete;
    request.IsDeprecated = !isUndelete;
    const updateResult = await connection.tooling.update('Package2', request).catch((err) => {
        if (err instanceof Error) {
            throw (0, packageUtils_1.applyErrorAction)((0, packageUtils_1.massageErrorMessage)(err));
        }
        throw err;
    });
    if (!updateResult.success) {
        throw (0, packageUtils_1.combineSaveErrors)('Package2', 'update', updateResult.errors);
    }
    return updateResult;
}
exports.deletePackage = deletePackage;
//# sourceMappingURL=packageDelete.js.map