"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Common = void 0;
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const core_1 = require("@salesforce/core");
const ts_types_1 = require("@salesforce/ts-types");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/plugin-auth', 'messages');
class Common {
    static async resolveLoginUrl(instanceUrl) {
        const logger = await core_1.Logger.child('Common', { tag: 'resolveLoginUrl' });
        if (instanceUrl) {
            throwIfLightning(instanceUrl);
            return instanceUrl;
        }
        let loginUrl;
        try {
            const project = await core_1.SfProject.resolve();
            const projectJson = await project.resolveProjectConfig();
            loginUrl = (0, ts_types_1.getString)(projectJson, 'sfdcLoginUrl', core_1.SfdcUrl.PRODUCTION);
        }
        catch (err) {
            const message = ((0, ts_types_1.isObject)(err) ? Reflect.get(err, 'message') ?? err : err);
            logger.debug(`error occurred while trying to determine loginUrl: ${message}`);
            loginUrl = core_1.SfdcUrl.PRODUCTION;
        }
        throwIfLightning(loginUrl);
        logger.debug(`loginUrl: ${loginUrl}`);
        return loginUrl;
    }
}
exports.Common = Common;
const throwIfLightning = (urlString) => {
    if (urlString?.match(/\.lightning\..*force\.com/)) {
        throw new core_1.SfError(messages.getMessage('lightningInstanceUrl'), 'LightningDomain', [
            messages.getMessage('flags.instance-url.description'),
        ]);
    }
};
//# sourceMappingURL=common.js.map