"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@salesforce/core");
const sf_plugins_core_1 = require("@salesforce/sf-plugins-core");
const flags_1 = require("../../../flags");
const exportApi_1 = require("../../../api/data/tree/exportApi");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/plugin-data', 'tree.export');
class Export extends sf_plugins_core_1.SfCommand {
    async run() {
        const { flags } = await this.parse(Export);
        const ux = new sf_plugins_core_1.Ux({ jsonEnabled: this.jsonEnabled() });
        const exportApi = new exportApi_1.ExportApi(flags['target-org'], ux);
        const exportConfig = {
            outputDir: flags['output-dir'],
            plan: flags.plan,
            prefix: flags.prefix,
            query: flags.query,
        };
        return exportApi.export(exportConfig);
    }
}
exports.default = Export;
Export.summary = messages.getMessage('summary');
Export.description = messages.getMessage('description');
Export.examples = messages.getMessages('examples');
Export.aliases = ['force:data:tree:export'];
Export.deprecateAliases = true;
Export.flags = {
    ...flags_1.orgFlags,
    query: sf_plugins_core_1.Flags.string({
        char: 'q',
        summary: messages.getMessage('flags.query'),
        required: true,
    }),
    plan: sf_plugins_core_1.Flags.boolean({
        char: 'p',
        summary: messages.getMessage('flags.plan'),
    }),
    prefix: sf_plugins_core_1.Flags.string({
        char: 'x',
        summary: messages.getMessage('flags.prefix'),
    }),
    'output-dir': sf_plugins_core_1.Flags.directory({
        char: 'd',
        summary: messages.getMessage('flags.outputdir'),
        aliases: ['outputdir'],
        deprecateAliases: true,
    }),
};
//# sourceMappingURL=tree.js.map