"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const fs = require("fs");
const core_1 = require("@salesforce/core");
const sf_plugins_core_1 = require("@salesforce/sf-plugins-core");
const kit_1 = require("@salesforce/kit");
const flags_1 = require("../../../../flags");
const batcher_1 = require("../../../../batcher");
const bulkUtils_1 = require("../../../../bulkUtils");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/plugin-data', 'bulk.delete');
class Delete extends sf_plugins_core_1.SfCommand {
    async run() {
        const { flags } = await this.parse(Delete);
        const conn = flags['target-org'].getConnection(flags['api-version']);
        this.spinner.start('Bulk Delete');
        await (0, bulkUtils_1.validateSobjectType)(flags.sobject, conn);
        const csvRecords = fs.createReadStream(flags.file, { encoding: 'utf-8' });
        const job = conn.bulk.createJob(flags.sobject, 'delete');
        const batcher = new batcher_1.Batcher(conn, new sf_plugins_core_1.Ux({ jsonEnabled: this.jsonEnabled() }), this.config.bin, this.config.pjson.oclif.topicSeparator ?? ':');
        // eslint-disable-next-line @typescript-eslint/no-misused-promises,no-async-promise-executor
        return new Promise(async (resolve, reject) => {
            job.on('error', (err) => {
                throw err;
            });
            try {
                resolve(await batcher.createAndExecuteBatches(job, csvRecords, flags.sobject, flags.wait?.minutes));
                this.spinner.stop();
            }
            catch (e) {
                this.spinner.stop('error');
                reject(e);
            }
        });
    }
}
exports.default = Delete;
Delete.examples = messages.getMessages('examples');
Delete.summary = messages.getMessage('summary');
Delete.description = messages.getMessage('description');
Delete.flags = {
    ...flags_1.orgFlags,
    file: sf_plugins_core_1.Flags.file({
        char: 'f',
        summary: messages.getMessage('flags.csvfile'),
        required: true,
        exists: true,
        aliases: ['csvfile'],
        deprecateAliases: true,
    }),
    sobject: sf_plugins_core_1.Flags.string({
        char: 's',
        summary: messages.getMessage('flags.sobjecttype'),
        required: true,
        aliases: ['sobjecttype'],
        deprecateAliases: true,
    }),
    wait: sf_plugins_core_1.Flags.duration({
        char: 'w',
        unit: 'minutes',
        summary: messages.getMessage('flags.wait'),
        min: 0,
        default: kit_1.Duration.minutes(0),
    }),
};
//# sourceMappingURL=delete.js.map