"use strict";
/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PackageVersionRetrieveCommand = void 0;
const path = require("path");
const sf_plugins_core_1 = require("@salesforce/sf-plugins-core");
const core_1 = require("@salesforce/core");
const packaging_1 = require("@salesforce/packaging");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/plugin-packaging', 'package_version_retrieve');
class PackageVersionRetrieveCommand extends sf_plugins_core_1.SfCommand {
    async run() {
        const { flags } = await this.parse(PackageVersionRetrieveCommand);
        const connection = flags['target-org'].getConnection(flags['api-version']);
        const options = {
            subscriberPackageVersionId: flags.package ?? '',
            destinationFolder: flags['output-dir'],
        };
        const result = await packaging_1.Package.downloadPackageVersionMetadata(this.project, options, connection);
        const results = [];
        result.converted?.forEach((component) => {
            if (component.xml) {
                results.push({
                    fullName: component.fullName,
                    type: component.type.name,
                    filePath: path.relative('.', component.xml),
                });
            }
            if (component.content) {
                results.push({
                    fullName: component.fullName,
                    type: component.type.name,
                    filePath: path.relative('.', component.content),
                });
            }
        });
        const columnData = {
            fullName: {
                header: messages.getMessage('headers.fullName'),
            },
            type: {
                header: messages.getMessage('headers.type'),
            },
            filePath: {
                header: messages.getMessage('headers.filePath'),
            },
        };
        this.table(results, columnData, { 'no-truncate': true });
        return results;
    }
}
exports.PackageVersionRetrieveCommand = PackageVersionRetrieveCommand;
PackageVersionRetrieveCommand.hidden = true;
PackageVersionRetrieveCommand.summary = messages.getMessage('summary');
PackageVersionRetrieveCommand.description = messages.getMessage('description');
PackageVersionRetrieveCommand.examples = messages.getMessages('examples');
PackageVersionRetrieveCommand.requiresProject = true;
PackageVersionRetrieveCommand.flags = {
    loglevel: sf_plugins_core_1.loglevel,
    'api-version': sf_plugins_core_1.orgApiVersionFlagWithDeprecations,
    'target-org': sf_plugins_core_1.requiredOrgFlagWithDeprecations,
    package: sf_plugins_core_1.Flags.string({
        char: 'p',
        summary: messages.getMessage('flags.package.summary'),
        required: true,
    }),
    'output-dir': sf_plugins_core_1.Flags.directory({
        char: 'd',
        summary: messages.getMessage('flags.outputDir.summary'),
        default: 'force-app',
    }),
};
//# sourceMappingURL=retrieve.js.map