import { Config, Command } from '@oclif/core';
import { AsyncCreatable } from '@salesforce/kit';
import { JsonMap, Optional } from '@salesforce/ts-types';
export type CommandExecutionOptions = {
    command: Partial<Command.Class>;
    argv: string[];
    config: Partial<Config>;
};
type PluginInfo = {
    name: Optional<string>;
    version: Optional<string>;
};
export declare class CommandExecution extends AsyncCreatable {
    status?: number;
    private specifiedFlags;
    private specifiedFlagFullNames;
    private command;
    private argv;
    private config;
    private vcs?;
    private orgId?;
    private devhubId?;
    private orgApiVersion?;
    private devhubApiVersion?;
    constructor(options: CommandExecutionOptions);
    /**
     * Determines whether the SFDX project is using GIT for version control or some other VCS.
     * Returns a token indicating the VCS for usage stats, or an empty string if the command
     * was executed outside of an SFDX project.
     */
    static resolveVCSInfo(): Promise<string>;
    toJson(): JsonMap;
    getPluginInfo(): PluginInfo;
    getCommandName(): string | undefined;
    protected init(): Promise<void>;
    private determineSpecifiedFlags;
}
export {};
