import { SourceComponent } from '@salesforce/source-deploy-retrieve';
import { RemoteChangeElement, ChangeResult } from './types';
export declare const getMetadataKey: (metadataType: string, metadataName: string) => string;
export declare const getKeyFromObject: (element: RemoteChangeElement | ChangeResult) => string;
export declare const supportsPartialDelete: (cmp: SourceComponent) => boolean;
export declare const isLwcLocalOnlyTest: (filePath: string) => boolean;
/**
 * Verify that a filepath starts exactly with a complete parent path
 * ex: '/foo/bar-extra/baz'.startsWith('foo/bar') would be true, but this function understands that they are not in the same folder
 */
export declare const pathIsInFolder: (filePath: string, folder: string) => boolean;
export declare const chunkArray: <T>(arr: T[], size: number) => T[][];
export declare const ensureRelative: (filePath: string, projectPath: string) => string;
export type ParsedCustomLabels = {
    CustomLabels: {
        labels: Array<{
            fullName: string;
        }>;
    };
};
/**
 * A method to help delete custom labels from a file, or the entire file if there are no more labels
 *
 * @param filename - a path to a custom labels file
 * @param customLabels - an array of SourceComponents representing the custom labels to delete
 * @returns -json equivalent of the custom labels file's contents OR undefined if the file was deleted/not written
 */
export declare const deleteCustomLabels: (filename: string, customLabels: SourceComponent[]) => Promise<ParsedCustomLabels | undefined>;
