import { Connection } from '@salesforce/core';
import { CancellationToken, Progress } from '../common';
import { AsyncTestRun } from '../streaming';
import { ApexTestProgressValue, ApexTestQueueItem, ApexTestResult, ApexTestRunResultRecord, AsyncTestArrayConfiguration, AsyncTestConfiguration, TestResult, TestRunIdResult } from './types';
export declare class AsyncTests {
    readonly connection: Connection;
    private readonly codecoverage;
    constructor(connection: Connection);
    /**
     * Asynchronous Test Runs
     * @param options test options
     * @param codeCoverage should report code coverage
     * @param exitOnTestRunId should not wait for test run to complete, return test run id immediately
     * @param progress progress reporter
     * @param token cancellation token
     */
    runTests(options: AsyncTestConfiguration | AsyncTestArrayConfiguration, codeCoverage?: boolean, exitOnTestRunId?: boolean, progress?: Progress<ApexTestProgressValue>, token?: CancellationToken): Promise<TestResult | TestRunIdResult>;
    /**
     * Report Asynchronous Test Run Results
     * @param testRunId test run id
     * @param codeCoverage should report code coverages
     * @param token cancellation token
     */
    reportAsyncResults(testRunId: string, codeCoverage?: boolean, token?: CancellationToken): Promise<TestResult>;
    checkRunStatus(testRunId: string, progress?: Progress<ApexTestProgressValue>): Promise<ApexTestRunResultRecord | undefined>;
    /**
     * Format the results of a completed asynchronous test run
     * @param asyncRunResult TestQueueItem and RunId for an async run
     * @param commandStartTime start time for the async test run
     * @param codeCoverage should report code coverages
     * @param testRunSummary test run summary
     * @param progress progress reporter
     * @returns
     */
    formatAsyncResults(asyncRunResult: AsyncTestRun, commandStartTime: number, codeCoverage: boolean, testRunSummary: ApexTestRunResultRecord, progress?: Progress<ApexTestProgressValue>): Promise<TestResult>;
    getAsyncTestResults(testQueueResult: ApexTestQueueItem): Promise<ApexTestResult[]>;
    private buildAsyncTestResults;
    /**
     * Abort test run with test run id
     * @param testRunId
     */
    abortTestRun(testRunId: string, progress?: Progress<ApexTestProgressValue>): Promise<void>;
    private getTestRunRequestAction;
}
