"use strict";
/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthInfoConfig = void 0;
const configFile_1 = require("./configFile");
/**
 * An auth config file that stores information such as access tokens, usernames, etc.,
 * in the global sfdx directory (~/.sfdx).
 *
 * ```
 * const authInfo = await AuthInfoConfig.create(AuthInfoConfig.getOptions(username));
 * ```
 */
class AuthInfoConfig extends configFile_1.ConfigFile {
    /**
     * Gets the config options for a given org ID.
     *
     * @param username The username for the org.
     */
    static getOptions(username) {
        return {
            isGlobal: true,
            isState: true,
            filename: `${username}.json`,
        };
    }
}
exports.AuthInfoConfig = AuthInfoConfig;
AuthInfoConfig.encryptedKeys = [/token/i, /password/i, /secret/i];
//# sourceMappingURL=authInfoConfig.js.map