"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStyledObject = exports.getStyledValue = void 0;
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const chalk = require("chalk");
const styledProperties = new Map([
    [
        'status',
        new Map([
            ['Active', chalk.green],
            ['else', chalk.red],
        ]),
    ],
    [
        'connectedStatus',
        new Map([
            ['Connected', chalk.green],
            ['else', chalk.red],
        ]),
    ],
]);
const getStyledValue = (key, value) => {
    if (!value)
        return value;
    const prop = styledProperties.get(key);
    if (!prop)
        return value;
    // I'm not sure how to type the inner Map so that it knows else is definitely there
    const chalkMethod = prop.get(value) ?? prop.get('else');
    return chalkMethod(value);
};
exports.getStyledValue = getStyledValue;
const getStyledObject = (objectToStyle) => {
    const clonedObject = { ...objectToStyle };
    return Object.fromEntries(Object.entries(clonedObject).map(([key, value]) => [key, (0, exports.getStyledValue)(key, value)]));
};
exports.getStyledObject = getStyledObject;
//# sourceMappingURL=orgHighlighter.js.map