import { Failures, FileProperties, FileResponse, Successes } from '@salesforce/source-deploy-retrieve';
import { CoverageReporterOptions, DefaultReportOptions } from '@salesforce/apex-node';
import { Ux } from '@salesforce/sf-plugins-core';
export interface ResultFormatterOptions {
    verbose?: boolean;
    quiet?: boolean;
    waitTime?: number;
    concise?: boolean;
    username?: string;
    coverageOptions?: CoverageReporterOptions;
    junitTestResults?: boolean;
    resultsDir?: string;
    testsRan?: boolean;
}
export type CoverageResultsFileInfo = Record<keyof Partial<typeof DefaultReportOptions>, string>;
export declare abstract class ResultFormatter {
    ux: Ux;
    options: ResultFormatterOptions;
    protected constructor(ux: Ux, options?: ResultFormatterOptions);
    isSuccess(): boolean;
    isVerbose(): boolean;
    isQuiet(): boolean;
    isConcise(): boolean;
    protected sortFileResponses(fileResponses: FileResponse[]): void;
    protected sortFileProperties(fileProperties: FileProperties[]): void;
    protected sortTestResults(results?: Failures[] | Successes[]): Failures[] | Successes[];
    protected asRelativePaths(fileResponses: FileResponse[]): void;
    protected displayOutputFileLocations(): void;
    protected getCoverageFileInfo(): CoverageResultsFileInfo;
    protected getJunitFileInfo(): string | undefined;
    abstract getJson(): any;
    abstract display(): void;
}
