import { DeployResult, FileResponse } from '@salesforce/source-deploy-retrieve';
import { Ux } from '@salesforce/sf-plugins-core';
import { ResultFormatter, ResultFormatterOptions } from '../resultFormatter';
export type PushResponse = {
    pushedSource: Array<Pick<FileResponse, 'filePath' | 'fullName' | 'state' | 'type'>>;
    replacements?: Record<string, string[]>;
};
export declare class PushResultFormatter extends ResultFormatter {
    protected results: DeployResult[];
    protected deletes: string[];
    protected fileResponses: FileResponse[];
    protected replacements: Map<string, string[]>;
    constructor(ux: Ux, options: ResultFormatterOptions, results: DeployResult[], deletes?: string[]);
    /**
     * Get the JSON output from the DeployResult.
     *
     * @returns a JSON formatted result matching the provided type.
     */
    getJson(): PushResponse;
    /**
     * Displays deploy results in human readable format.  Output can vary based on:
     *
     * 1. Verbose option
     * 3. Checkonly deploy (checkonly=true)
     * 4. Deploy with test results
     * 5. Canceled status
     */
    display(): void;
    protected correctFileResponses(): FileResponse[];
    protected displaySuccesses(): void;
    protected displayReplacements(): void;
    protected displayFailures(): void;
    private componentsFromFilenames;
    private resolveComponentsOrWarn;
}
export declare const mergeReplacements: (results: DeployResult[]) => DeployResult['replacements'];
